@@ -10,6 +10,7 @@ import java.io.IOException;
 import java.lang.reflect.Method;
 import java.net.URI;
 import java.util.List;
+import java.util.Set;
 
 import javax.imageio.ImageIO;
 import javax.swing.JFileChooser;
@@ -35,7 +36,6 @@ import org.mutoss.gui.dialogs.RObjectLoadingDialog;
 import org.mutoss.gui.dialogs.TextFileViewer;
 import org.mutoss.gui.dialogs.VariableNameDialog;
 import org.mutoss.gui.graph.GraphView;
-import org.mutoss.gui.graph.NetList;
 import org.mutoss.gui.options.OptionsDialog;
 
 public class MenuBarMGraph extends JMenuBar implements ActionListener {
@@ -74,27 +74,129 @@ public class MenuBarMGraph extends JMenuBar implements ActionListener {
 		JMenu menu = new JMenu("Example graphs");
 		menu.setMnemonic(KeyEvent.VK_X);
 
-		menu.add(makeMenuItem("Bonferroni-Holm Test", "bht"));
-		menu.addSeparator();
-		menu.add(makeMenuItem("Parallel Gatekeeping with 4 Hypotheses", "pg"));
-		menu.add(makeMenuItem("Improved Parallel Gatekeeping with 4 Hypotheses", "pgi"));
-		menu.addSeparator();
-		menu.add(makeMenuItem("Example graph from Bretz et al. (2009)", "bretzEtAl"));
-		menu.add(makeMenuItem("Example graph from Hommel et al. (2007)", "hommelEtAl"));
+		JMenu subMenu = new JMenu("Common test procedures for any number of hypotheses");		
+		subMenu.add(makeMenuItem("Bonferroni-Holm procedure", "bht"));
+		subMenu.add(makeMenuItem("Fixed sequence test", "fixedSequence", false));
+		subMenu.add(makeMenuItem("Fallback procedure", "fallback", false));
+		menu.add(subMenu);
+		
+		subMenu = new JMenu("3 unstructured hypotheses");
+		subMenu.add(makeMenuItem("Improved fallback procedure I", "fallbackI", false));
+		subMenu.add(makeMenuItem("Improved fallback procedure II", "fallbackII", false));
+		menu.add(subMenu);		
+		
+		subMenu = new JMenu("2 primary & 2 secondary hypotheses");		
+		subMenu.add(makeMenuItem("Parallel Gatekeeping with 4 Hypotheses", "pg"));
+		subMenu.add(makeMenuItem("Improved Parallel Gatekeeping with 4 Hypotheses", "pgi"));
+		subMenu.addSeparator();
+		subMenu.add(makeMenuItem("Truncated Holm procedure", "truncHolm", false));
+		subMenu.addSeparator();
+		subMenu.add(makeMenuItem("General successive graph", "gSuccessive", false));
+		subMenu.add(makeMenuItem("Simple successive graph I", "successiveI", false));
+		subMenu.add(makeMenuItem("Simple successive graph II", "successiveII", false));
+		subMenu.addSeparator();
+		subMenu.add(makeMenuItem("Graph from Hung and Wang (2010)", "hung"));
+		menu.add(subMenu);
+		
+		/*subMenu = new JMenu("3 primary & 2 secondary hypotheses");		
+		subMenu.add(makeMenuItem("Graph from Bauer et al. (2001)", "bauer", false));
+		subMenu.add(makeMenuItem("Graph from Bretz et al. (2011)", "bretEtAl4", false));
+		menu.add(subMenu);*/
+		
+		subMenu = new JMenu("Miscellaneous");		
+		subMenu.add(makeMenuItem("Graph I from Bretz et al. (2011)", "bretzEtAl"));		
+		subMenu.add(makeMenuItem("Graph II from Bretz et al. (2011)", "bretzEtAl3"));
+		subMenu.addSeparator();
+		subMenu.add(makeMenuItem("Graph from Hommel et al. (2007)", "hommelEtAl"));
+		subMenu.addSeparator();
+		subMenu.add(makeMenuItem("Graph for a drug clinical trial from Maurer et al. (1995)", "maurer1995"));
+		menu.add(subMenu);
+		/*
+		Common test procedures
+		  Bonferroni-Holm procedure [Input: "Number of hypotheses"] (1)
+		  Fixed sequence test [Input: "Number of hypotheses"] (2, 3)
+		  Fallback procedure [Input: "Number of hypotheses"; "Initial weights"] (4)
+		3 unstructured hypotheses
+		  Improved fallback procedure - 1 [Input: "Initial weights"] (5)
+		  Improved fallback procedure - 2 [Input: "Initial weights"] (6)
+		2 primary & 2 secondary hypotheses
+		  Parallel gatekeeper (7)
+		  Improved parallel gatekeeper (8)
+		  Truncated Holm procedure (9)
+		  General successive graph [Input: w, omega, tau] (10)
+		    Simple successive graph - 1 (11, 12)
+		    Simple successive graph - 2 (11)
+		  Hung and Wang (2010) [Input: omega, tau, nu] (13)
+		3 primary & 2 secondary hypotheses
+		  Bauer et al. (2001) (14)
+		  Bretz et al. (2011) (10)
+		2 primary & 3 secondary hypotheses
+		  Bretz et al. (2009) - 1 (8)
+		  Bretz et al. (2009) - 2 (8)
+		  Bretz et al. (2009) - 3 (8)
+		Others
+		  Hommel et al. (2007), simplified (15)
+		  
+References:
+(1) Holm S. A simple sequentally rejective multiple test procedure. Scandinavian Journal of Statistics 1979; 6:65–70.
+(2) Maurer W, Hothorn L, Lehmacher W. Multiple comparisons in drug clinical trials and preclinical assays: a-priori ordered hypotheses. In Biometrie in der chemisch-pharmazeutischen Industrie, Vollmar J (ed.). Fischer Verlag:
+Stuttgart, 1995; 3–18.
+(3) Westfall PH, Krishen A. Optimally weighted, fixed sequence, and gatekeeping multiple testing procedures. Journal of Statistical Planning and Inference 2001; 99:25–40.
+(4) Wiens BL. A fixed sequence Bonferroni procedure for testing multiple endpoints. Pharmaceutical Statistics 2003; 2:211–215.
+(5) Wiens BL, Dmitrienko A. The fallback procedure for evaluating a single family of hypotheses. Journal of Biopharmaceutical Statistics 2005; 15:929–942.
+(6) Hommel G, Bretz F. Aesthetics and power considerations in multiple testing—a contradiction? Biometrical Journal 2008; 50:657–666.
+(7) Dmitrienko A, Offen WW, Westfall PH. Gatekeeping strategies for clinical trials that do not require all primary effects to be significant. Statistics in Medicine 2003; 22:2387–2400.
+(8) Bretz F, Maurer W, Brannath W, Posch M. A graphical approach to sequentially rejective multiple test procedures. Statistics in Medicine 2009; 28:586--604.
+(9) Dmitrienko A, Tamhane A, Wiens B. General multi-stage gatekeeping procedures. Biometrical Journal 2008; 50:667–677.
+(10) Bretz F, Maurer W, Hommel G Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine 2011; (in press).
+(11) Maurer W, Glimm E, Bretz F. Multiple and repeated testing of primary, co-primary and secondary hypotheses. Statistics in Biopharmaceutical Reserach 2011; (in press).
+(12) Bretz, Posch, Glimm, Klinglmueller, Maurer, Rohmeyer (2012) Graphical approaches for multiple comparison procedures using weighted Bonferroni, Simes or parametric tests. Biometrical Journal (in press).
+(13) Hung HMJ, Wang SJ. Challenges to multiple testing in clinical trials. Biometrical Journal 2010; (in press).
+(14) Bauer P, Brannath W, Posch M. Multiple testing for identifying effective and safe treatments. Biometrical Journal 2001; 43:605–616.
+(15) Hommel G, Bretz F, Maurer W. Powerful short-cuts for multiple testing procedures with special reference to gatekeeping strategies. Statistics in Medicine 2007; 26:4063–4073. 
+		   */
 
 		add(menu);
 
 		menu = new JMenu("Analysis");
 		menu.setMnemonic(KeyEvent.VK_A);
-		
+
 		menu.add(makeMenuItem("Graph analysis", "graphAnalysis"));
 		menu.addSeparator();
 		menu.add(makeMenuItem("Power analysis", "powerAnalysis"));		
 
 		add(menu);
-		
-        addExtrasMenu();
-        addHelpMenu();
+
+		menu = new JMenu("Extras");
+		menu.add(makeMenuItem("Options", "showOptions", KeyEvent.VK_O));
+		menu.add(makeMenuItem("Set all options back to default", "clearOptions", KeyEvent.VK_C));
+		menu.addSeparator();
+		menu.add(makeMenuItem("Change Layout of graph", "changeGraphLayout", KeyEvent.VK_G));
+		menu.add(makeMenuItem("Set variables to specific real values", "replaceVariables", KeyEvent.VK_V));
+		menu.addSeparator();
+		menu.add(makeMenuItem("Log", "showLog", KeyEvent.VK_L));
+		menu.add(makeMenuItem("Report error", "reportError", KeyEvent.VK_R));
+		menu.add(makeMenuItem("Submit your own graph to gMCP archive", "submitGraph", false));
+		if (System.getProperty("eclipse") != null) {		
+			menu.add(makeMenuItem("Debug console", "debugConsole", KeyEvent.VK_D));
+		}
+		menu.setMnemonic(KeyEvent.VK_E);
+		add(menu);
+
+		menu = new JMenu("Help");
+		menu.setMnemonic(KeyEvent.VK_H);
+		menu.add(makeMenuItem("About", "showAbout", KeyEvent.VK_B));         
+		menu.add(makeMenuItem("Introduction to gMCP", "showAppHelp", KeyEvent.VK_I));
+		menu.add(makeMenuItem("Weighted parametric tests defined by graphs", "showParametric", KeyEvent.VK_P));
+		menu.add(makeMenuItem("gMCP R Online Reference manual", "showManual", KeyEvent.VK_M));
+		menu.add(makeMenuItem("References", "showReferences", KeyEvent.VK_R));
+		//menu.add(makeMenuItem("Theoretical Background", "showAppHelp"));
+		/*menu.addSeparator();
+         menu.add(makeMenuItem("Description of Edges with Infinitesimal Small Epsilon Weights", "showEpsDoc"));*/
+		menu.addSeparator();
+		menu.add(makeMenuItem("Version Info / NEWS", "showNEWS", KeyEvent.VK_N));
+		add(menu);
+
 	}
 	
 	private void createLastUsed() {
@@ -144,13 +246,9 @@ public class MenuBarMGraph extends JMenuBar implements ActionListener {
 		return item;
 	}
 
-
 	public void loadGraph(String string) {
-		NetList nl = control.getNL();		
-		newGraph();
-		boolean matrix = RControl.getR().eval("is.matrix("+string+")").asRLogical().getData()[0];
-		RControl.getR().eval(nl.initialGraph + " <- gMCP:::arrangeNodes("+ (matrix?"matrix2graph(":"(")+ string + "))");
-		nl.loadGraph();
+		control.getNL().loadGraph(string);
+		control.setGraphName(string);
 		control.getMainFrame().validate();
 	}
 
@@ -216,19 +314,24 @@ public class MenuBarMGraph extends JMenuBar implements ActionListener {
         	loadGraph();
         } else if (e.getActionCommand().equals("load graph from R")) {
         	new RObjectLoadingDialog(control.getGraphGUI());
-        	//VariableNameDialog vnd = new VariableNameDialog(control.getGraphGUI());
         	createLastUsed();        	
         } else if (e.getActionCommand().equals("bht")) {
-        	new NumberOfHypotheses(control.getGraphGUI(), this, "createBonferroniHolmGraph");        	
+        	new NumberOfHypotheses(control.getGraphGUI(), this, "BonferroniHolmGraph");        	
         } else if (e.getActionCommand().equals("pg")) {       	
-        	loadGraph("createGraphForParallelGatekeeping()");
+        	loadGraph("graphForParallelGatekeeping()");
         } else if (e.getActionCommand().equals("pgi")) {       	
-        	loadGraph("createGraphForImprovedParallelGatekeeping()");
+        	loadGraph("graphForImprovedParallelGatekeeping()");
         } else if (e.getActionCommand().equals("bretzEtAl")) {       	
-        	loadGraph("createGraphFromBretzEtAl()");
+        	loadGraph("graphFromBretzEtAl2009()");
+        } else if (e.getActionCommand().equals("bretzEtAl3")) {       	
+        	loadGraph("graph2FromBretzEtAl2009()");
         } else if (e.getActionCommand().equals("hommelEtAl")) {       	
-        	loadGraph("createGraphFromHommelEtAl()");
-        } else if (e.getActionCommand().equals("showLog")) {       	
+        	loadGraph("graphFromHommelEtAl2007()");
+        } else if (e.getActionCommand().equals("hung")) { 	
+        	loadGraph("graphFromHungEtWang2010()");
+        } else if (e.getActionCommand().equals("maurer1995")) {     	
+        	loadGraph("graphFromMaurerEtAl1995()");
+        } else if (e.getActionCommand().equals("showLog")) {    	
         	showLog();
         } else if (e.getActionCommand().equals("reportError")) {       	
         	 reportError();
@@ -239,15 +342,9 @@ public class MenuBarMGraph extends JMenuBar implements ActionListener {
         } else if (e.getActionCommand().equals("showParametric")) {
         	showFile("doc/correlated.pdf");       	 	
         } else if (e.getActionCommand().equals("showManual")) {
-        	try {	
-				Method main = Class.forName("java.awt.Desktop").getDeclaredMethod("getDesktop");
-				Object obj = main.invoke(new Object[0]);
-				Method second = obj.getClass().getDeclaredMethod("browse", new Class[] { URI.class }); 
-				second.invoke(obj, new URI("http://cran.at.r-project.org/web/packages/gMCP/gMCP.pdf"));
-			} catch (Exception exc) {			
-				logger.warn("No Desktop class in Java 5 or URI error.");
-				RControl.getR().eval("browseURL(\"http://cran.at.r-project.org/web/packages/gMCP/gMCP.pdf\")");
-			}
+        	showURL("http://cran.at.r-project.org/web/packages/gMCP/gMCP.pdf");
+        } else if (e.getActionCommand().equals("showReferences")) {
+        	showFile("References.html");
         } else if (e.getActionCommand().equals("showEpsDoc")) {
         	showFile("doc/EpsilonEdges.pdf");       	 	
         } else if (e.getActionCommand().equals("showNEWS")) {
@@ -285,9 +382,29 @@ public class MenuBarMGraph extends JMenuBar implements ActionListener {
 				JOptionPane.showMessageDialog(this, "Error loading values from R:\n"+ex.getMessage(), 
 						"Error loading values from R", JOptionPane.ERROR_MESSAGE);
 			} 
-        }
+        } else if (e.getActionCommand().equals("changeGraphLayout")) {
+        	notYetSupported();
+        } else if (e.getActionCommand().equals("replaceVariables")) {
+        	Set<String> variables = control.getNL().getAllVariables();
+        	if (variables.isEmpty() || (variables.size()==1 && variables.contains("ε"))) {
+        		JOptionPane.showMessageDialog(control.getMainFrame(), "No variables to replace!", "No variables to replace!", JOptionPane.INFORMATION_MESSAGE);
+        	}
+        	control.getNL().saveGraphWithoutVariables(control.getNL().initialGraph, false);
+        	control.getNL().loadGraph();
+        } 
 	}
 	
+	private void showURL(String url) {
+		try {	
+			Method main = Class.forName("java.awt.Desktop").getDeclaredMethod("getDesktop");
+			Object obj = main.invoke(new Object[0]);
+			Method second = obj.getClass().getDeclaredMethod("browse", new Class[] { URI.class }); 
+			second.invoke(obj, new URI(url));
+		} catch (Exception exc) {			
+			logger.warn("No Desktop class in Java 5 or URI error.");
+			RControl.getR().eval("browseURL(\""+url+"\")");
+		}	}
+
 	private void notYetSupported() {
 		JOptionPane.showMessageDialog(control.getMainFrame(), "Not yet supported.", "Not yet supported", JOptionPane.INFORMATION_MESSAGE);
 	}
@@ -311,6 +428,10 @@ public class MenuBarMGraph extends JMenuBar implements ActionListener {
 				second.invoke(obj, f);
 			} catch (Exception exc) {			
 				logger.warn("No Desktop class in Java 5 or URI error.");
+				if (f.getName().toLowerCase().endsWith(".html") || f.getName().toLowerCase().endsWith(".htm")) {
+					RControl.getR().eval("browseURL(\"file://"+f.getAbsolutePath()+"\")");
+					return;
+				}
 				try {
 					if (OSTools.isWindows()) {
 						Process p;							
@@ -529,42 +650,5 @@ public class MenuBarMGraph extends JMenuBar implements ActionListener {
         item.addActionListener(this);
         return (item);
     }
-    
-    public void addExtrasMenu() {
-        add(makeExtrasMenu());
-    }
-
-    public JMenu makeExtrasMenu() {
-    	JMenu menu = new JMenu(localizer.getString("SGTK_MENU_EXTRAS"));
-    	menu.add(makeMenuItem(localizer.getString("SGTK_MENU_EXTRAS_OPTIONS"), "showOptions", KeyEvent.VK_O));
-    	menu.add(makeMenuItem("Set all options back to default", "clearOptions", KeyEvent.VK_C));
-    	menu.addSeparator();
-    	menu.add(makeMenuItem(localizer.getString("SGTK_MENU_EXTRAS_LOG"), "showLog", KeyEvent.VK_L));
-    	menu.add(makeMenuItem(localizer.getString("SGTK_MENU_EXTRAS_REPORT_ERROR"), "reportError", KeyEvent.VK_R));
-    	if (System.getProperty("eclipse") != null) {		
-    		menu.add(makeMenuItem("Debug console", "debugConsole", KeyEvent.VK_D));
-    	}
-    	menu.setMnemonic(KeyEvent.VK_E);
-    	return menu;
-    }
-    
-    public void addHelpMenu() {
-    	add(makeHelpMenu());
-    }
-    
-    private JMenu makeHelpMenu() {
-    	 JMenu menu = new JMenu("Help");
-    	 menu.setMnemonic(KeyEvent.VK_H);
-         menu.add(makeMenuItem("About", "showAbout", KeyEvent.VK_B));         
-         menu.add(makeMenuItem("Introduction to gMCP", "showAppHelp", KeyEvent.VK_I));
-         menu.add(makeMenuItem("Weighted parametric tests defined by graphs", "showParametric", KeyEvent.VK_P));
-         menu.add(makeMenuItem("gMCP R Online Reference manual", "showManual", KeyEvent.VK_M));
-         //menu.add(makeMenuItem("Theoretical Background", "showAppHelp"));
-         /*menu.addSeparator();
-         menu.add(makeMenuItem("Description of Edges with Infinitesimal Small Epsilon Weights", "showEpsDoc"));*/
-         menu.addSeparator();
-         menu.add(makeMenuItem("Version Info / NEWS", "showNEWS", KeyEvent.VK_N));
-         return menu;
-	}	
 
 }
