@@ -89,6 +89,10 @@ public class GraphView extends JPanel implements ActionListener {
 		add("Center", sPane);
     }
 	
+	public void setGraphName(String name) {
+		this.name = name;
+	}
+
 	public JPanel getNorthPanel() {
 		JPanel panel = new JPanel();
 		panel.setLayout(new BorderLayout());
@@ -183,8 +187,9 @@ public class GraphView extends JPanel implements ActionListener {
 			getNL().statusBar.setText("Click on the graph panel to place the node.");
 		} else if (e.getSource().equals(buttonConfInt)) {
 			if (!getNL().isTesting()) {
-				getNL().saveGraph();
 				getPView().savePValues();
+				getNL().saveGraphWithoutVariables(getNL().initialGraph, false);
+	        	getNL().loadGraph();
 			}
 			if (getNL().getKnoten().size()==0) {
 				JOptionPane.showMessageDialog(parent, "Please create first a graph.", "Please create first a graph.", JOptionPane.ERROR_MESSAGE);
@@ -210,7 +215,9 @@ public class GraphView extends JPanel implements ActionListener {
 			}
 		} else if (e.getSource().equals(buttonStart)) {
 			if (!getNL().isTesting()) {
-				parent.glassPane.start();
+				getNL().saveGraphWithoutVariables(getNL().initialGraph, false);
+	        	getNL().loadGraph();
+				parent.glassPane.start();				
 				startTesting();
 				correlation = parent.getPView().getCorrelation();
 				SwingWorker<Void, Void> worker = new SwingWorker<Void, Void>() {
@@ -235,7 +242,8 @@ public class GraphView extends JPanel implements ActionListener {
 				JOptionPane.showMessageDialog(parent, "Please create first a graph.", "Please create first a graph.", JOptionPane.ERROR_MESSAGE);				
 			} else {
 				if (!getNL().isTesting()) {
-					getNL().saveGraph();
+					getNL().saveGraphWithoutVariables(getNL().initialGraph, false);
+		        	getNL().loadGraph();
 					getPView().savePValues();
 				}
 				parent.glassPane.start();
@@ -335,5 +343,9 @@ public class GraphView extends JPanel implements ActionListener {
 	public String getGMCPOptions() {
 		return ","+getPView().getPValuesString()+ correlation+", alpha="+getPView().getTotalAlpha()+", eps="+Configuration.getInstance().getGeneralConfig().getEpsilon();
 	}
+
+	public DView getDView() {
+		return 	parent.getDView();	
+	}
 	
 }
